"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.definition = void 0;
exports.definition = {
    site: 'beyond-hd',
    name: 'Beyond-HD',
    description: 'Without BeyondHD, your HDTV is just a TV',
    language: 'en-US',
    type: 'private',
    encoding: 'UTF-8',
    links: ['https://beyond-hd.me/'],
    caps: {
        categorymappings: [
            { id: '1', cat: 'Movies', desc: 'Movies' },
            { id: '2', cat: 'TV', desc: 'TV' },
        ],
        modes: {
            search: ['q', 'imdbid'],
            'tv-search': ['q', 'season', 'ep', 'imdbid'],
            'movie-search': ['q', 'imdbid'],
        },
    },
    settings: [
        { name: 'username', type: 'text', label: 'Username' },
        { name: 'password', type: 'password', label: 'Password' },
        {
            name: 'sort',
            type: 'select',
            label: 'Sort requested from site',
            default: 'created_at',
            options: {
                created_at: 'created',
                seeders: 'seeders',
                size: 'size',
                name: 'title',
            },
        },
        {
            name: 'type',
            type: 'select',
            label: 'Order requested from site',
            default: 'desc',
            options: { desc: 'desc', asc: 'asc' },
        },
    ],
    login: {
        path: 'login',
        method: 'form',
        form: 'form[action$="/login"]',
        captcha: {
            type: 'text',
            selector: 'div[style*="#999999;"]',
            input: 'key',
        },
        inputs: {
            username: '{{ .Config.username }}',
            password: '{{ .Config.password }}',
            remember: 'on',
        },
        selectorinputs: {
            _token: { selector: 'input[name="_token"]', attribute: 'value' },
        },
        error: [
            { selector: 'form[action$="/login"] .text-red' },
            {
                selector: 'script:contains("toastr.error")',
                message: { selector: 'script:contains("toastr.error")' },
            },
        ],
    },
    search: {
        paths: [{ path: 'torrents' }],
        inputs: {
            $raw: '{{ range .Categories }}categories[]={{.}}&{{end}}',
            search: '{{ if .Query.IMDBID }}{{else}}{{ .Keywords }}{{end}}',
            description: '',
            uploader: '',
            imdb: '{{ .Query.IMDBIDShort }}',
            tmdb: '',
            sorting: '{{ .Config.sort }}',
            direction: '{{ .Config.type }}',
            qty: 100,
        },
        rows: { selector: 'table > tbody > tr', after: 1 },
        fields: {
            _category: {
                selector: 'a[href*="/categories/"]',
                optional: true,
                attribute: 'href',
                filters: [{ name: 'regexp', args: '/categories/.*?\\.(\\d+)' }],
            },
            category: {
                text: '{{if .Result._category}}{{.Result._category}}{{else}}1{{end}}',
            },
            title: { selector: 'a.torrent-name' },
            download: {
                selector: 'a[href*="/download/"]',
                attribute: 'href',
            },
            details: { selector: 'a.torrent-name', attribute: 'href' },
            banner: {
                optional: true,
                selector: 'div.torrent-poster img',
                attribute: 'src',
                filters: [{ name: 'replace', args: ['/img/person.png', ''] }],
            },
            date: {
                selector: 'td:not(a[href$="/history"]) span.text-orange',
                filters: [{ name: 'timeago' }],
            },
            size: { selector: 'td span.text-blue' },
            seeders: { selector: 'a[href$="/peers"] span.text-green' },
            leechers: { selector: 'a[href$="/peers"] span.text-red' },
            grabs: { selector: 'a[href$="/history"]' },
            imdb: {
                optional: true,
                selector: 'a[href*="www.imdb.com/title/tt"]',
                attribute: 'href',
            },
            downloadvolumefactor: {
                case: {
                    'i[data-original-title="100% Free"]': 0,
                    'i[data-original-title="100% Free (Limited UL)"]': 0,
                    'i[data-original-title="25% Promo"]': 0.75,
                    'i[data-original-title="50% Promo"]': 0.5,
                    'i[data-original-title="75% Promo"]': 0.25,
                    '*': 1,
                },
            },
            uploadvolumefactor: { text: 1 },
        },
    },
    source: 'jackett',
};
