"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.definition = void 0;
exports.definition = {
    site: 'tvchaosuk',
    name: 'TVChaosUK',
    description: 'TV Chaos UK (TVCUK) is a Private Torrent Tracker for UK TV',
    language: 'en-UK',
    type: 'private',
    encoding: 'UTF-8',
    links: ['https://tvchaosuk.com/'],
    caps: {
        categorymappings: [
            { id: '53', cat: 'Other', desc: 'None' },
            { id: '29', cat: 'TV', desc: 'Comedy' },
            { id: '5', cat: 'TV/Documentary', desc: 'Documentary' },
            { id: '11', cat: 'TV', desc: 'Drama' },
            { id: '14', cat: 'TV', desc: 'Entertainment' },
            { id: '19', cat: 'TV', desc: 'Factual' },
            { id: '43', cat: 'TV', desc: 'Foreign' },
            { id: '32', cat: 'TV', desc: 'Kids/Family' },
            { id: '44', cat: 'Movies', desc: 'Movies' },
            { id: '45', cat: 'TV', desc: 'News & Current Affairs' },
            { id: '51', cat: 'Audio', desc: 'Radio' },
            { id: '52', cat: 'TV', desc: 'Reality' },
            { id: '30', cat: 'TV', desc: 'Soaps' },
            { id: '33', cat: 'TV', desc: 'Sci-Fi' },
            { id: '42', cat: 'TV/Sport', desc: 'Sport' },
            { id: '4', cat: 'TV', desc: 'Holding Bin' },
        ],
        modes: {
            search: ['q', 'imdbid'],
            'tv-search': ['q', 'season', 'ep', 'imdbid'],
            'movie-search': ['q', 'imdbid'],
        },
    },
    settings: [
        { name: 'username', type: 'text', label: 'Username' },
        { name: 'password', type: 'password', label: 'Password' },
        {
            name: 'sort',
            type: 'select',
            label: 'Sort requested from site',
            default: 'created_at',
            options: {
                created_at: 'created',
                seeders: 'seeders',
                size: 'size',
                name: 'title',
            },
        },
        {
            name: 'type',
            type: 'select',
            label: 'Order requested from site',
            default: 'desc',
            options: { desc: 'desc', asc: 'asc' },
        },
    ],
    login: {
        path: 'login',
        method: 'form',
        form: 'form[action$="/login"]',
        inputs: {
            username: '{{ .Config.username }}',
            password: '{{ .Config.password }}',
            remember: 'on',
        },
        selectorinputs: {
            _token: { selector: 'input[name="_token"]', attribute: 'value' },
        },
        error: [{ selector: 'div#ERROR_COPY' }],
    },
    ratio: {
        path: '/',
        selector: 'li:has(i.fa-sync-alt)',
        filters: [{ name: 'regexp', args: 'Ratio : (\\d+)' }],
    },
    search: {
        paths: [{ path: 'torrents/filter' }],
        inputs: {
            $raw: '{{ range .Categories }}categories[]={{.}}&{{end}}',
            search: '{{ if .Query.IMDBID }}{{else}}{{ .Keywords }}{{end}}',
            description: '',
            uploader: '',
            imdb: '{{ .Query.IMDBIDShort }}',
            tvdb: '',
            tmdb: '',
            mal: '',
            igdb: '',
            sorting: '{{ .Config.sort }}',
            sort: '{{ .Config.sort }}',
            direction: '{{ .Config.type }}',
            qty: 100,
        },
        rows: { selector: 'table > tbody > tr' },
        fields: {
            category: {
                selector: 'a[href*="/categories/"]',
                attribute: 'href',
                filters: [{ name: 'regexp', args: '/categories/(\\d+)' }],
            },
            title: { selector: 'a.view-torrent' },
            download: {
                selector: 'a[href*="/download/"]',
                attribute: 'href',
            },
            details: { selector: 'a.view-torrent', attribute: 'href' },
            banner: {
                optional: true,
                selector: 'div.torrent-poster img',
                attribute: 'src',
                filters: [
                    {
                        name: 'replace',
                        args: ['https://via.placeholder.com/600x900', ''],
                    },
                ],
            },
            comments: { selector: 'a[href*="#comments"]', attribute: 'href' },
            size: { selector: 'td:nth-last-child(4)' },
            seeders: { selector: 'td:nth-last-child(3)' },
            leechers: { selector: 'td:nth-last-child(2)' },
            grabs: {
                selector: 'td:nth-last-child(1)',
                filters: [{ name: 'regexp', args: '(\\d+)' }],
            },
            imdb: {
                optional: true,
                selector: 'a[href*="www.imdb.com/title/tt"]',
                attribute: 'href',
            },
            date: {
                selector: 'time',
                filters: [
                    {
                        name: 're_replace',
                        args: [
                            '(?i)(önce|tagasi|geleden|fa|temu|siden|há|atrás|nazpět|назад|acum|în urmă|hace|il y a|vor|преди|前)',
                            ' ago',
                        ],
                    },
                    {
                        name: 're_replace',
                        args: [
                            '(?i)(minutit|minutter|minuti|minuty|minutos|минуты|минут|Minuten|минути|minuten)',
                            'minutes',
                        ],
                    },
                    {
                        name: 're_replace',
                        args: ['(?i)(dakika|minut|minuto|minuta|minutt|минута|Minute|minuut|分钟)', ' minute'],
                    },
                    {
                        name: 're_replace',
                        args: [
                            '(?i)(tundi|timer|ore|godziny|horas|hodiny|hoden|часа|часов|ore|heures|Stunden)',
                            'hours',
                        ],
                    },
                    {
                        name: 're_replace',
                        args: [
                            '(?i)(saat|tund|time|ora|godzina|hora|hodina|час|oră|heure|Stunde|uur|小时)',
                            ' hour',
                        ],
                    },
                    {
                        name: 're_replace',
                        args: [
                            '(?i)(päeva|dage|giorni|dni|dias|dny|дня|дней|zile|días|jours|Tagen|дни|dagen)',
                            'days',
                        ],
                    },
                    {
                        name: 're_replace',
                        args: ['(?i)(gün|päev|dag|giorno|dzień|dia|den|день|zi|día|jour|Tag|ден|天)', ' day'],
                    },
                    {
                        name: 're_replace',
                        args: [
                            '(?i)(nädalat|uger|settimane|tygodnie|uker|semanas|týdny|недели|недель|săptămâni|semaines|Wochen|седмици|weken)',
                            'weeks',
                        ],
                    },
                    {
                        name: 're_replace',
                        args: [
                            '(?i)(hafta|nädal|uge|settimana|tydzień|uke|semana|týden|неделю|săptămână|semaine|Woche|седмица|周)',
                            ' week',
                        ],
                    },
                    { name: 're_replace', args: ['(?i) (ay)', 'month'] },
                    {
                        name: 're_replace',
                        args: [
                            '(?i)(kuud|måneder|mesi|miesiące|meses|měsíce|месяца|месяцев|luni|meses|mois|Monaten|месеца|maanden)',
                            'months',
                        ],
                    },
                    {
                        name: 're_replace',
                        args: [
                            '(?i)(kuu|måned|mese|miesiąc|mês|měsíc|месяц|lună|mes|Monat|месец|maand|个月)',
                            ' month',
                        ],
                    },
                    {
                        name: 're_replace',
                        args: ['(?i)(aastat|anni|lata|anos|roky|года|ani|años|ans|Jahren|години)', ' years'],
                    },
                    {
                        name: 're_replace',
                        args: ['(?i)(yil|aasta|år|anno|rok|ano|год|año|Jahr|година|jaar|年)', ' year'],
                    },
                    { name: 're_replace', args: ['(?i) (an)', 'year'] },
                ],
            },
            downloadvolumefactor: {
                case: {
                    'i[class*="fa-id-badge text-orange"]': 0,
                    'i[class*="fa-trophy text-purple"]': 0,
                    'i[class*="fa-star text-bold"]': 0,
                    'i[class*="fa-coins text-bold"]': 0,
                    'i[class*="fa-globe text-blue"]': 0,
                    'i[class*="fa-star text-gold"]': 0,
                    'i[class*="fa-certificate text-pink"]': 0,
                    '*': 1,
                },
            },
            uploadvolumefactor: {
                case: {
                    'i[class*="fa-gem text-green"]': 2,
                    'i[class*="fa-globe text-green"]': 2,
                    'i[class*="fa-certificate text-pink"]': 2,
                    '*': 1,
                },
            },
        },
    },
    source: 'jackett',
};
